import { Meta, Canvas, Controls } from "@storybook/blocks";
import * as Storyname from "./tabs-integration.stories";

<Meta of={Storyname} name="Docs" />

# Tabs Integration

How to integrate the tab component:

1- Wrap the content of the tabs in the `ux-tab-container`, and add the follwing props if they are needed:

-   `fix-to-top` if the tab header should remain sticky upon scrolling
-   `scroll-when-activated` if there should be a scroll to the tab header element upon click on a tab
-   `active-tab`: the `tab-id` prop of the tab that should be active, if not set, the first tab component will be activated.

2- Wrap the content of each tab in the `ux-tab` component providing the prop `name` for the name to be displayed in the tab button,
and the `tab-id` of the respective tab. Additonally add utility classes for spacing. <br />

### Integration Example

```
<ux-tab-container
    fix-to-top
    scroll-when-activated
    active-tab="tabOverview"
>
    <!-- LOOP THROUGH THE CONTENT OF THE TABS -->
    <ux-tab
        name="Production Status"
        tab-id="tabOverview"
        class="u-marginTop-60"
    >
        <!-- INSERT THE CONTENT OF THE TAB HERE -->
    </ux-tab>
    <ux-tab
        name="Production"
        tab-id="tabApplications"
        class="u-marginTop-60"
    >
        <!-- INSERT THE CONTENT OF THE TAB HERE -->
    </ux-tab>
    <ux-tab
        name="Lieferumfang"
        tab-id="tabDeliveryScope"
        class="u-marginTop-60"
    >
        <!-- INSERT THE CONTENT OF THE TAB HERE -->
    </ux-tab>
</ux-tab-container>
```

## Tab Integration in Product page (K.4)

<Canvas of={Storyname.Default}></Canvas>

## Product Page with anchor navigation

If the tabs should be displayed in the form of an anchor navigation, with all the contents of the
tabs visible stacked on top of each other, simply add the `anchor-navigation` attribute to the `ux-tab-container`
component. For a better usability ion terms of user experience, make also sure to add the `fix-to-top` attribute.

<Canvas of={Storyname.AnchorNavigation}></Canvas>
